/**
 * Copyright © 2012-2020 by Data Virtuality GmbH
 */
package com.google.code.or.common.glossary;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Dmitry Pogorelov
 * @date 2020.05.01
 */
public enum OptionalFieldType {
	SIGNEDNESS(1),                      // Signedness of numeric colums
	DEFAULT_CHARSET(2),                 // Charsets of character columns
	COLUMN_CHARSET(3),                  // Charsets of character columns
	COLUMN_NAME(4),                     // Names of columns
	SET_STR_VALUE(5),                   // The string values of SET columns
	ENUM_STR_VALUE(6),                  // The string values is ENUM columns
	GEOMETRY_TYPE(7),                   // The real type of geometry columns
	SIMPLE_PRIMARY_KEY(8),              // The primary key without any prefix
	PRIMARY_KEY_WITH_PREFIX(9),         // The primary key with some prefix
	ENUM_AND_SET_DEFAULT_CHARSET(10),   // Charsets of ENUM and SET columns
	ENUM_AND_SET_COLUMN_CHARSET(11);    // Charsets of ENUM and SET columns

	private final int code;

	OptionalFieldType(int code) {
		this.code = code;
	}

	public int getCode() {
		return code;
	}

	private static final Map<Integer, OptionalFieldType> INDEX_BY_CODE;

	static {
		INDEX_BY_CODE = new HashMap<>();
		for (OptionalFieldType fieldType : values()) {
			INDEX_BY_CODE.put(fieldType.code, fieldType);
		}
	}

	public static OptionalFieldType byCode(int code) {
		return INDEX_BY_CODE.get(code);
	}
}
