/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * Modified by
 * @author  Data Virtuality GmbH
 * @date    $Date$
 *  
 */
package com.google.code.or.common.glossary.column;

import com.google.code.or.common.glossary.Column;
import com.google.code.or.common.glossary.UnsignedLong;
import com.google.code.or.common.util.CodecUtils;
import java.math.BigInteger;

/**
 * 
 * @author Jingqi Xu
 */
public final class LongLongColumn implements Column {
	//
	private static final long serialVersionUID = 4159913884779393654L;

	//
	private final BigInteger value;

	/**
	 * 
	 */
	private LongLongColumn(long value) {
		if(value < 0) {
			// Convert to positive value
			this.value = new BigInteger(1, CodecUtils.toByteArray(value));
		} else {
			this.value = BigInteger.valueOf(value);
		}
	}

	/**
	 * 
	 */
	@Override
	public String toString() {
		return value.toString();
	}

	/**
	 * 
	 */
	public BigInteger getValue() {
		return this.value;
	}
	
	/**
	 * 
	 */
	public static final LongLongColumn valueOf(long value) {
		return new LongLongColumn(value);
	}
}
