/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * Modified by
 * @author  Data Virtuality GmbH
 * @date    $Date$
 *  
 */
package com.google.code.or.common.glossary.column;

import com.google.code.or.common.glossary.Column;

/**
 * 
 * @author Jingqi Xu
 *
 * 09.02.2015 Dmitry Pogorelov DVCORE-2597
 *      - added support of boolean values via TinyColumn type
 */
public final class TinyColumn implements Column {
	//
	private static final long serialVersionUID = 3629858638897033423L;
	
	//
	public static final int MIN_VALUE = -128;
	public static final int MAX_VALUE = 127;

	//
	public static final int UNSIGNED_MIN_VALUE = 0;
	public static final int UNSIGNED_MAX_VALUE = 255;

	//
	private static final TinyColumn[] CACHE = new TinyColumn[256];
	static {
		for(int i = 0; i < CACHE.length; i++) {
			CACHE[i] = new TinyColumn(i + Byte.MIN_VALUE);
		}
	}

	//
	public static final TinyColumn TRUE = TinyColumn.valueOf(1);
	public static final TinyColumn FALSE = TinyColumn.valueOf(0);

	//
	private final int value;

	/**
	 * 
	 */
	private TinyColumn(int value) {
		this.value = value;
	}
	
	/**
	 * 
	 */
	@Override
	public String toString() {
		return String.valueOf(this.value);
	}

	/**
	 * 
	 */
	public Integer getValue() {
		return this.value;
	}
	
	/**
	 * 
	 */
	public static final TinyColumn valueOf(int value) {
		if ((value < MIN_VALUE || value > MAX_VALUE) && (value < UNSIGNED_MIN_VALUE || value > UNSIGNED_MAX_VALUE))
			throw new IllegalArgumentException("invalid value: " + value);
		final int index = value - Byte.MIN_VALUE;
		return (index >= 0 && index < CACHE.length) ? CACHE[index] : new TinyColumn(value);
	}
}
