/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * Modified by
 * @author  Data Virtuality GmbH
 * @date    $Date$
 *  
 */
package com.google.code.or.common.util;

import java.net.Socket;

import com.google.code.or.io.XInputStream;
import com.google.code.or.io.XOutputStream;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * 
 * @author Jingqi Xu
 */
public final class IOUtils {
	//
	private static final Logger LOGGER = LoggerFactory.getLogger(IOUtils.class);


	/**
	 *
	 */
	public static void closeQuietly(Socket socket) {
		try {
			socket.close();
		} catch(Exception e) {
			LOGGER.error("Unexpected error when closing socket", e);
		}
	}
	
	public static void closeQuietly(XInputStream is) {
		try {
			is.close();
		} catch(Exception e) {
			LOGGER.error("Unexpected error when closing input stream", e);
		}
	}
	
	public static void closeQuietly(XOutputStream os) {
		try {
			os.close();
		} catch(Exception e) {
			LOGGER.error("Unexpected error when closing output stream", e);
		}
	}
}
