/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * Modified by
 * @author  Data Virtuality GmbH
 * @date    $Date$
 *  
 */
package com.google.code.or.common.util;

/**
 * 
 * @author Jingqi Xu
 *
 * 12.02.2015 Dmitry Pogorelov DVCORE-2597
 *      - added support of toShortString method
 * 17.02.2015 Dmitry Pogorelov DVCORE-2597
 *      - added default constructor, additional append method
 */
public final class ToStringBuilder {
	//
	private int count;
	private final StringBuilder builder = new StringBuilder(32);

	public ToStringBuilder() {}

	public ToStringBuilder(String name) {
		this.builder.append(name).append("[");
	}

	/**
	 * 
	 */
	public ToStringBuilder(Object object) {
		String name = ClassUtils.getShortClassName(object.getClass().getName());
		this.builder.append(name).append("[");
	}

	/**
	 * 
	 */
	@Override
	public String toString() {
		return toString(true);
	}

	public String toString(boolean addBracket) {
		if (addBracket) this.builder.append("]");
		return this.builder.toString();
	}

	/**
	 * 
	 */
	public ToStringBuilder append(String key, int value) {
		if(count++ > 0) this.builder.append(',');
		this.builder.append(key).append('=').append(value);
		return this;
	}
	
	public ToStringBuilder append(String key, long value) {
		if(count++ > 0) this.builder.append(',');
		this.builder.append(key).append('=').append(value);
		return this;
	}
	
	public ToStringBuilder append(String key, byte value) {
		if(count++ > 0) this.builder.append(',');
		this.builder.append(key).append('=').append(value);
		return this;
	}
	
	public ToStringBuilder append(String key, String value) {
		if(count++ > 0) this.builder.append(',');
		this.builder.append(key).append('=').append(value == null ? "<null>" : value);
		return this;
	}
	
	public ToStringBuilder append(String key, Object value) {
		if(count++ > 0) this.builder.append(',');
		this.builder.append(key).append('=').append(value == null ? "<null>" : value);
		return this;
	}

	public ToStringBuilder append(String value) {
		this.builder.append(value);
		return this;
	}
}
