package com.google.code.or;

import com.google.code.or.binlog.impl.event.RotateEvent;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.concurrent.TimeUnit;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.code.or.binlog.BinlogEventListener;
import com.google.code.or.binlog.BinlogEventV4;

public class OpenReplicatorTest {
	//
	private static final Logger LOGGER = LoggerFactory.getLogger(OpenReplicatorTest.class);

	private static Counter counter = new Counter();

	/**
	 *
	 */
	public static void main(String args[]) throws Exception {
		//
		final OpenReplicator or = new OpenReplicator();
		counter.refresh();
		try {
			or.setUser("root");
			or.setPassword("sasa");
			or.setHost("127.0.0.1");
			or.setPort(3308);
			or.setServerId(1234);
			or.setBinlogPosition(4);
			or.setBinlogFileName("bin-log.000001");

			or.connect();

			LOGGER.info("Start replicator...");
			or.setBinlogEventListener(new BinlogEventListener() {
				public void onEvents(BinlogEventV4 event) {
					counter.next();
					if (event instanceof RotateEvent) {
						RotateEvent rotateEvent = (RotateEvent) event;
						String newBinlogFileName = rotateEvent.getBinlogFileName().toString();
						LOGGER.info("There was Rotate Event=" + newBinlogFileName + ". Handling...");
					}
				}
			});
			or.start();

			//
			LOGGER.info("press 'q' to stop");
			final BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
			for(String line = br.readLine(); line != null; line = br.readLine()) {
				if(line.equals("q")) {
					or.stop(0L, TimeUnit.MILLISECONDS);
					or.disconnect();
					break;
				}
			}
		} catch (Exception e) {
			LOGGER.error(e.toString());
			throw e;
		} finally {
			LOGGER.info("Finish replicator...");
			or.disconnect();
			counter.refresh();
		}
	}

	private static class Counter {
		private long totalCount;
		private long timeout = TimeUnit.SECONDS.toMillis(10);
		private long startTime;

		public void next() {
			totalCount++;
			if (startTime == 0) startTime = System.currentTimeMillis();
			checkCount();
		}

		private void checkCount() {
			if (System.currentTimeMillis() - startTime >= timeout) {
				LOGGER.info("Number of read events: " + totalCount);
				startTime = System.currentTimeMillis();
			}
		}

		public void refresh() {
			totalCount = 0L;
			startTime = 0L;
		}
	}
}
